==> tuia-client-0.2.45-20170605.074630-7-sources.jar: cn/com/tuia/advert/order/model/AdvertOrderJsonDO.java <==
package cn.com.tuia.advert.order.model;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月30日 10:00
 * @descript:
 * @version: 1.0
 */
public class AdvertOrderJsonDO implements Serializable {

    private static final long serialVersionUID = -876648220225174081L;

    /**
     * 广告定向配置包
     */
    private Long              advertOrientationId;

    /**
     * 发券次数
     */
    private Integer           times;

    /** 策略类型 @StrategyTypeEnum */
    private String            strategyType;
    
    /**轮流投放类型*/
    private String            turnsStrategyType;

    /** 计费方式,1:CPC; 2:CPA */
    private Integer           chargeType;

    /** 当前出价 */
    private Long              fee;
    
    /**userType*/
    private String            uT;
    
    /**duibaActivityType*/
    private String            acT;

    private Boolean           isPrivilege;

    /**
     * chargeType.
     *
     * @return the chargeType
     */
    public Integer getChargeType() {
        return chargeType;
    }

    /**
     * chargeType.
     *
     * @param chargeType the chargeType to set
     */
    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    /**
     * fee.
     *
     * @return the fee
     */
    public Long getFee() {
        return fee;
    }

    /**
     * fee.
     *
     * @param fee the fee to set
     */
    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Long getAdvertOrientationId() {
        return advertOrientationId;
    }

    public void setAdvertOrientationId(Long advertOrientationId) {
        this.advertOrientationId = advertOrientationId;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }

    public String getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(String strategyType) {
        this.strategyType = strategyType;
    }

    
    public String getTurnsStrategyType() {
        return turnsStrategyType;
    }

    
    public void setTurnsStrategyType(String turnsStrategyType) {
        this.turnsStrategyType = turnsStrategyType;
    }

    
    public String getuT() {
        return uT;
    }

    
    public void setuT(String uT) {
        this.uT = uT;
    }

    
    public String getAcT() {
        return acT;
    }

    
    public void setAcT(String acT) {
        this.acT = acT;
    }

    public Boolean getPrivilege() {
        return isPrivilege;
    }

    public void setPrivilege(Boolean privilege) {
        isPrivilege = privilege;
    }
}

==> tuia-client-0.2.52-20170626.081206-3-sources.jar: cn/com/tuia/advert/order/model/AdvertOrderJsonDO.java <==
package cn.com.tuia.advert.order.model;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月30日 10:00
 * @descript:
 * @version: 1.0
 */
public class AdvertOrderJsonDO implements Serializable {

    private static final long serialVersionUID = -876648220225174081L;

    /**
     * 广告定向配置包
     */
    private Long              advertOrientationId;

    /**
     * 发券次数
     */
    private Integer           times;

    /** 策略类型 @StrategyTypeEnum */
    private String            strategyType;
    
    /**轮流投放类型*/
    private String            turnsStrategyType;

    /** 计费方式,1:CPC; 2:CPA */
    private Integer           chargeType;

    /** 当前出价 */
    private Long              fee;
    
    /**userType*/
    private String            uT;
    
    /**duibaActivityType*/
    private String            acT;

    private Boolean           isPrivilege;
    
    private Long              aFee;
    
    private Long              accountId;
    
    private Long              agentId;

    /**
     * chargeType.
     *
     * @return the chargeType
     */
    public Integer getChargeType() {
        return chargeType;
    }

    /**
     * chargeType.
     *
     * @param chargeType the chargeType to set
     */
    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    /**
     * fee.
     *
     * @return the fee
     */
    public Long getFee() {
        return fee;
    }

    /**
     * fee.
     *
     * @param fee the fee to set
     */
    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Long getAdvertOrientationId() {
        return advertOrientationId;
    }

    public void setAdvertOrientationId(Long advertOrientationId) {
        this.advertOrientationId = advertOrientationId;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }

    public String getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(String strategyType) {
        this.strategyType = strategyType;
    }

    
    public String getTurnsStrategyType() {
        return turnsStrategyType;
    }

    
    public void setTurnsStrategyType(String turnsStrategyType) {
        this.turnsStrategyType = turnsStrategyType;
    }

    
    public String getuT() {
        return uT;
    }

    
    public void setuT(String uT) {
        this.uT = uT;
    }

    
    public String getAcT() {
        return acT;
    }

    
    public void setAcT(String acT) {
        this.acT = acT;
    }

    public Boolean getPrivilege() {
        return isPrivilege;
    }

    public void setPrivilege(Boolean privilege) {
        isPrivilege = privilege;
    }

    
    public Long getaFee() {
        return aFee;
    }

    
    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    
    public Long getAccountId() {
        return accountId;
    }

    
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    
    public Long getAgentId() {
        return agentId;
    }

    
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    
}
